@@ -53,8 +53,6 @@ public:
 
     ContextManager* contextManager() const;
 
-    bool currentDocumentIsRasterImage() const;
-
     void setDistractionFreeMode(bool);
 
 public Q_SLOTS:
@@ -93,28 +91,12 @@ private Q_SLOTS:
     void toggleSideBar(bool visible);
     void updateToggleSideBarAction();
     void slotModifiedDocumentListChanged();
-
-    /**
-     * Init all the file list stuff. This should only be necessary when
-     * Gwenview is started with an image as a parameter (in this case we load
-     * the image before looking at the content of the image folder)
-     */
     void slotPartCompleted();
-
-    /**
-     * If an image is loaded but there is no item selected for it in the file
-     * view, this function will select the corresponding item if it comes up in
-     * list.
-     */
     void slotDirModelNewItems();
-
-    /**
-     * If no image is selected, select the first one available.
-     */
     void slotDirListerCompleted();
-    void slotDirListerRedirection(const KUrl& newUrl);
 
     void slotSelectionChanged();
+    void slotCurrentDirUrlChanged(const KUrl& url);
 
     void goToPrevious();
     void goToNext();
