@@ -48,8 +48,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #endif
 
 #ifdef GWENVIEW_SEMANTICINFO_BACKEND_NEPOMUK
-#include <nepomuk/resourcemanager.h>
-#include <nepomuk/tag.h>
+#include <Nepomuk2/ResourceManager>
+#include <Nepomuk2/Tag>
 #endif
 
 namespace Gwenview
@@ -107,7 +107,7 @@ struct StartMainPagePrivate : public Ui_StartMainPage
     void setupSearchUi()
     {
 #ifdef GWENVIEW_SEMANTICINFO_BACKEND_NEPOMUK
-        if (Nepomuk::ResourceManager::instance()->init() == 0) {
+        if (Nepomuk2::ResourceManager::instance()->init() == 0) {
             mTagView->setModel(TagModel::createAllTagsModel(mTagView, mGvCore->semanticInfoBackEnd()));
             mTagView->show();
             mTagLabel->hide();
@@ -207,6 +207,8 @@ StartMainPage::StartMainPage(QWidget* parent, GvCore* gvCore)
     d->updateHistoryTab();
     connect(GwenviewConfig::self(), SIGNAL(configChanged()),
             SLOT(loadConfig()));
+
+    d->mRecentFoldersView->setFocus();
 }
 
 StartMainPage::~StartMainPage()
@@ -221,8 +223,8 @@ void StartMainPage::slotTagViewClicked(const QModelIndex& index)
         return;
     }
     // FIXME: Check label encoding
-    Nepomuk::Tag tagr(index.data().toString());
-    KUrl url = KUrl(tagr.resourceUri()).url();
+    Nepomuk2::Tag tagr(index.data().toString());
+    KUrl url = KUrl(tagr.uri()).url();
     emit urlSelected(url);
 #endif
 }
@@ -273,6 +275,10 @@ void StartMainPage::showEvent(QShowEvent* event)
             d->mRecentFoldersView->setItemDelegate(delegate);
             d->mRecentFoldersView->setThumbnailWidth(128);
             d->mRecentFoldersView->setCreateThumbnailsForRemoteUrls(false);
+            QModelIndex index = d->mRecentFoldersView->model()->index(0, 0);
+            if (index.isValid()) {
+                d->mRecentFoldersView->setCurrentIndex(index);
+            }
         }
         if (!d->mRecentUrlsView->model()) {
             d->mRecentUrlsView->setModel(d->mGvCore->recentUrlsModel());
@@ -334,4 +340,9 @@ void StartMainPage::loadConfig()
     applyPalette(d->mGvCore->palette(GvCore::NormalViewPalette));
 }
 
+ThumbnailView* StartMainPage::recentFoldersView() const
+{
+    return d->mRecentFoldersView;
+}
+
 } // namespace
